@@ -1,4 +1,7 @@
-`choro.legend` <- function (px, py, sh, under = "under", over = "over", between = "to", 
+
+#Original code by Chris Brunsdon
+#Edited by Binbin Lu
+choro.legend <- function (px, py, sh, under = "under", over = "over", between = "to", 
                             fmt = "%g", cex=1, ...) 
   {
     x = sh$breaks
@@ -14,4 +17,4 @@
     temp <- legend(x = px, y = py, legend = rep(" ", length(res)), 
                    fill = sh$cols, text.width = maxwidth, cex=cex,...)
     text(temp$rect$left + temp$rect$w, temp$text$y, res, pos = 2, cex=cex)
-  }
+  }
\ No newline at end of file
